@@ -6,14 +6,19 @@
 //!
 //! However the hash function is still pervasively used in other contextes where security is still
 //! ok (e.g. hmac-sha1), so on this basis is available here.
+//!
+//! # Example
+//!
+//! ```
+//! use cryptoxide::{sha1::Sha1, digest::Digest};
+//!
+//! let mut digest = [0u8; 20];
+//! let mut context = Sha1::new();
+//! context.input(b"hello world");
+//! context.result(&mut digest);
+//! ```
 
-// Licensed under the Apache License, Version 2.0 <LICENSE-APACHE or
-// http://www.apache.org/licenses/LICENSE-2.0> or the MIT license
-// <LICENSE-MIT or http://opensource.org/licenses/MIT>, at your
-// option. This file may not be copied, modified, or distributed
-// except according to those terms.
-
-use crate::cryptoutil::{read_u32v_be, write_u32_be, FixedBuffer, FixedBuffer64, StandardPadding};
+use crate::cryptoutil::{read_u32v_be, write_u32_be, FixedBuffer};
 use crate::digest::Digest;
 use crate::simd::u32x4;
 
@@ -307,7 +312,7 @@ pub fn sha1_digest_block_u32(state: &mut [u32; 5], block: &[u32; 16]) {
 /// The schedule-related functions can be used to easily perform 4 rounds
 /// of the message work schedule update calculation, as shown below:
 ///
-/// ```ignore
+/// ```no_check
 /// macro_rules! schedule_x4 {
 ///     ($v0:expr, $v1:expr, $v2:expr, $v3:expr) => (
 ///         sha1msg2(sha1msg1($v0, $v1) ^ $v2, $v3)
@@ -353,7 +358,7 @@ fn add_input(st: &mut Sha1, msg: &[u8]) {
     // Assumes that msg.len() can be converted to u64 without overflow
     st.length_bits = add_bytes_to_bits(st.length_bits, msg.len() as u64);
     let st_h = &mut st.h;
-    st.buffer.input(msg, |d: &[u8]| {
+    st.buffer.input(msg, |d| {
         sha1_digest_block(st_h, d);
     });
 }
@@ -362,7 +367,7 @@ fn mk_result(st: &mut Sha1, rs: &mut [u8]) {
     if !st.computed {
         let st_h = &mut st.h;
         st.buffer
-            .standard_padding(8, |d: &[u8]| sha1_digest_block(&mut *st_h, d));
+            .standard_padding(8, |d| sha1_digest_block(&mut *st_h, d));
         write_u32_be(st.buffer.next(4), (st.length_bits >> 32) as u32);
         write_u32_be(st.buffer.next(4), st.length_bits as u32);
         sha1_digest_block(st_h, st.buffer.full_buffer());
@@ -382,7 +387,7 @@ fn mk_result(st: &mut Sha1, rs: &mut [u8]) {
 pub struct Sha1 {
     h: [u32; STATE_LEN],
     length_bits: u64,
-    buffer: FixedBuffer64,
+    buffer: FixedBuffer<64>,
     computed: bool,
 }
 
@@ -392,7 +397,7 @@ impl Sha1 {
         let mut st = Sha1 {
             h: [0u32; STATE_LEN],
             length_bits: 0u64,
-            buffer: FixedBuffer64::new(),
+            buffer: FixedBuffer::new(),
             computed: false,
         };
         st.reset();
